import { Component } from '@angular/core';
import { ModalController } from '@ionic/angular/standalone';
import { IonicModule } from '@ionic/angular';
import { FlowExecutor } from '../lib/flow.executor';
import { MockProgressTask, MockRetryTask, MockSuccessTask } from './mock-tasks/mock-tasks';
import { FlowDisplayComponent } from '../lib/flow-display/flow-display.component';
import { TriageResultComponent } from './consult-tasks/triage-result/triage-result.component';
import { TriageTask } from './consult-tasks/consult-tasks';
import { SymptomInputModalComponent } from './consult-tasks/symptom-input/symptom-input.modal';
import { getUserForm } from '../lib/tasks/task-user-form/get-user-form';
import { JobIntentionTask, UserBasicInfoTask, UserInterestsTask } from './job-workflow/task.job';

@Component({
  selector: 'app-page-flow-test',
  templateUrl: './page-flow-test.component.html',
  styleUrls: ['./page-flow-test.component.scss'],
  imports: [
    IonicModule,
    FlowDisplayComponent,
    TriageResultComponent,
    SymptomInputModalComponent
  ],
  standalone: true,
})
export class PageFlowTestComponent {

  private executor = new FlowExecutor(3, true);

  constructor(
    private modalCtrl: ModalController
  ) {

  }

  async getForm() {
    const fieldList = [
      { type: "String", key: "name", name: "姓名", required: true },
      { type: "String", key: "mobile", name: "手机", required: true },
      {
        type: "Radio", key: "gender", name: "性别", required: false, options: [
          { label: "男", value: "male" },
          { label: "女", value: "female" }
        ]
      }
    ];

    try {
      const result = await getUserForm({ modalCtrl: this.modalCtrl, fieldList });
      console.log('Collected data:', result);
      return result;
    } catch (error) {
      console.error('Form error:', error);
      return null;
    }
  }

  async jobWorkflow() {
    // 创建工作流
    const workflow = {
      title: '求职信息收集',
      desc: '请填写您的求职相关信息',
      taskList: [
        new UserBasicInfoTask(this.modalCtrl),
        new JobIntentionTask(this.modalCtrl),
        new UserInterestsTask(this.modalCtrl)
      ]
    };

    this.executor.setWorkflow(workflow);
    const modal = await this.modalCtrl.create({
      component: FlowDisplayComponent,
      componentProps: { executor: this.executor }
    });

    await modal.present();
    await this.executor.start();
  }
  async startWorkflow() {
    // 创建工作流
    const workflow = {
      title: '示例工作流',
      desc: '演示工作流执行过程',
      taskList: [
        new MockSuccessTask(),
        new MockRetryTask(),
        new MockProgressTask()
      ]
    };

    this.executor.setWorkflow(workflow);
    const modal = await this.modalCtrl.create({
      component: FlowDisplayComponent,
      componentProps: { executor: this.executor }
    });

    await modal.present();
    await this.executor.start();
  }

  // 问诊任务
  async startTriage() {
    this.executor.setWorkflow({
      title: '医疗分诊流程',
      taskList: [new TriageTask({ modalCtrl: this.modalCtrl })]
    });

    this.executor.taskSuccess$.subscribe(task => {
      if (task instanceof TriageTask) {
        this.showTriageResult(task);
      }
    });

    await this.executor.start();
  }

  private async showTriageResult(task: TriageTask) {
    const modal = await this.modalCtrl.create({
      component: TriageResultComponent,
      componentProps: {
        symptom: task.getData('symptomDescription'),
        department: task.getData('department'),
        reason: task.getData('triageReason')
      }
    });

    await modal.present();
  }
}
